pub struct ErofsFile { /* private fields */ }Expand description
An implementation of an EROFS file backed by a Zircon Pager VMO.
Implementations
Sourceimpl ErofsFile
impl ErofsFile
Sourcepub fn new(
volume: Arc<ErofsVolume>,
node: FileNode,
) -> Result<Arc<Self>, Status>
pub fn new( volume: Arc<ErofsVolume>, node: FileNode, ) -> Result<Arc<Self>, Status>
Creates a new pager-backed ErofsFile using Arc::new_cyclic to establish a weak
self-reference within the registered ErofsPacketReceiver. This permits the file to be
kept alive dynamically when being used by clients, and cleaned up when no longer in use.
pub fn fs(&self) -> &ErofsFilesystem
pub fn node(&self) -> &FileNode
pub fn vmo(&self) -> &Vmo
Sourcepub fn watch_for_zero_children(&self) -> Result<bool, Status>
pub fn watch_for_zero_children(&self) -> Result<bool, Status>
Instructs the pager to watch for the VMO_ZERO_CHILDREN signal.
If the VMO is currently held weakly by the packet receiver, this method upgrades it to a
Strong reference to prevent the file from being deallocated while clients have active
mappings, and registers the signal wait on the VMO. Returns Ok(true) if a transition to
Strong occurred.